import os
import logging
from pathlib import Path
from typing import Optional

from .process_controller import start_process

default_logger = logging.getLogger(__name__)

current_file_path = os.path.dirname(os.path.realpath(__file__))


def find_java_bin(extra_location: str = None):
    locations = [
        f"../../../../gateway/jre/bin/java{'.exe' if os.name == 'nt' else ''}",
        "/opt/dynatrace/gateway/jre/bin/java",
        "C:/Program Files/dynatrace/gateway/jre/bin/java.exe",
        "D:/Program Files/dynatrace/gateway/jre/bin/java.exe",
    ]
    if extra_location:
        locations.insert(0, extra_location)

    for location in locations:
        if Path(location).exists():
            return location

    if os.environ.get("GATEWAY_HOME", False):
        return f"{os.environ.get('GATEWAY_HOME')}/jre/bin/java"

    return "java"


def query(endpoint_id: int, temp_folder: Path, env=None, java_path: Optional[str] = None) -> None:
    cmd_args = [
        "-cp",
        os.path.join(current_file_path, "../jars/*"),
        "com.dynatrace.jdbc.connector.Main",
        "-endpoint",
        f"{endpoint_id}",
        "-tempfolder",
        f"{temp_folder}",
    ]
    cmd = [find_java_bin(java_path), *cmd_args]
    start_process(cmd, env=env)
